function [a,awc] = awc1D(profX,pixel_size)
% AWC1D computes the averaged wavelet coefficient spectrum of a 1D profile
% following the approach of Simonsen et al. (1998)
% This functions requires the MATLAB WAVELET TOOLBOX!
% Input parameters:
% profX => a linearly spaced vector containing the heights of a
% 1D-signal
% pixel_size => distance between points of the vector profX
% Output parameters:
% a => scale parameter (m^-1)
% awc => averaged wavelet coefficient spectrum

% Daubechies wavelet of order 4 used as basis

N = 64;%wmaxlev(length(profX),'db4');
[C,L] = wavedec(profX,N,'db4');

for i = 1:N
    a(i) = 2*pixel_size*L(length(L))/L(length(L)-i);
    D = detcoef(C,L,i);
    awc(i) = mean(abs(D));
end
