clear
clc
close all

load example.csv
h = (example(:,1));
x = (example(:,2));
dx = (example(:,3));
% h -> heights of a 1D signal 
% x -> x-positions of discrete measurements 
% dx-> distance between measurements 
  
% remove any linear trend from the data 
h1 = detrend(h);                
  
%plot the stylolite  
figure (1)
plot (x,h1); 
title('stylolite'); 
xlabel ('x [mm]'), ylabel ('y [mm]'), axis equal; 
grid on;
  
% calculate the averaged wavelet coefficient spectrum
[a ps] = awc1D(h1, dx(1));  

% do a logarithmic binning of the power spectrum 
intervall   = 1.5;        % define intervall  
[x_av,y_av] = logbin1D(a,ps,intervall); 
  
% plot original and binned power spectrum in log-log space  
figure (2) 
loglog(a(1:end),ps(1:end),'r',x_av(1:end),y_av(1:end),'b*-');
%loglog(a(1:end),ps(1:end),'r'); 
title ('Average wavelet spectrum') 
legend('original data', 'binnded data'); 
grid on;
hold on  
xlabel('a[mm]'); ylabel('awc(a)'); 
  
% non-linear data fitting (using the built in function LSQNONLIN) to 
% estimate the crossover length L 
% set options for LSQNONLIN 
options = optimset('Largescale','off','MaxFunEvals', 500);  
  
% used signal filter to cut noise:
lowCut = 0;
highCut = 0;
% define dataset used for minimization 
X = x_av(1+lowCut:end-highCut);                 
Y = y_av(1+lowCut:end-highCut);                 
  
% STARTING GUESS MINIMIZATION: 
minimizeAll=1;
if minimizeAll ~= 1
    % minimization for L*, hL*, Hs and Hl 
    usedL = [0.5 1];   
    usedLowerLimits = [];
    usedUpperLimits = [];
else
    %minimization for Lx* and Ly* (Hs & Hl are fixed) 
    usedL = [1 1 1 0.5];
    usedLowerLimits = [];
    usedUpperLimits = [];
end
HSmall = 0.9; % right part of cor spectrum
HLarge = 0.7; % left part of cor spectrum

% Invoke optimization using LSQNONLIN (see Matlab help for details) 
[new_L,resnorm] = lsqnonlin(@nonlin_cor_diff,usedL,usedLowerLimits, usedUpperLimits,options,X,Y, HSmall, HLarge); 

if length(new_L)==4
    HSUsed = new_L(3);
    HLUsed = new_L(4);
else
    HSUsed = HSmall;
    HLUsed = HLarge;
end

%calculate the model with minimized coefficients  
samplevector = linspace(min(X),max(X),500); 
Y_bin        = nonlin_cor_model(new_L,samplevector, HSUsed, HLUsed);  

% Plot the original and modeled data with fixed slopes   
figure (3) 
loglog (x_av, y_av,'+r',samplevector,exp(Y_bin),'b'),hold on; 
loglog  (1/new_L(1),new_L(2),'*g') 
line([(x_av(end-highCut)) (x_av(end-highCut))],ylim,'Color',[1 0 0])
line([(x_av(1+lowCut)) (x_av(1+lowCut))],ylim,'Color',[1 0 0])
title   ('Average wavelet spectrum') 
legend  ('binned data','modelled fit',... 
    sprintf('%s%1.3f%s', 'lc = ',1/new_L(1),'mm'), ...
    'signal filter')
if minimizeAll==1
    xlabel(sprintf('%s\n%s %1.3f %s %1.3f\n%s', 'a [mm]', 'Hurst exponents: Hs=', HSUsed, ', Hl=', HLUsed, 'Nonlinear fitted values: lc, Hs, Hl'));
else
    xlabel(sprintf('%s\n%s %1.3f %s %1.3f\n%s', 'a [mm]', 'Hurst exponents: Hs=', HSUsed, ', Hl=', HLUsed, 'Nonlinear fitted values: lc'));
end
ylabel('awc(a)');
grid on;
 
