clear
clc
close all

load example.csv
h = (example(:,1));
x = (example(:,2));
dx = (example(:,3));
% h -> heights of a 1D signal
% x -> x-positions of discrete measurements
% dx-> distance between measurements

% remove any linear trend from the data
h1 = detrend(h);

%plot the stylolite
figure (1)
plot (x,h1);
title('stylolite');
xlabel ('x [mm]'), ylabel ('y [mm]'), axis equal;

% calculate the Fourier power spectrum
[k,ps] = fourier1D(h1,dx);

% do a logarithmic binning of the power spectrum
intervall   = 1.5;        % define intervall 1.5
[x_av,y_av] = logbin1D(k,ps,intervall);

% plot original and binned power spectrum in log-log space
figure (2)
loglog(k(2:end),ps(2:end),'r',x_av(2:end),y_av(2:end),'b*-');
title ('Fourier power spectrum')
legend('original data','binned data');
hold on
xlabel('k [mm^{-1}]'); ylabel('ps(k)');

% non-linear data fitting (using the built in function LSQNONLIN) to
% estimate the crossover length L
% set options for LSQNONLIN
options = optimset('Largescale','off','MaxFunEvals', 500);

% define dataset used for minimization 
% used signal filter to cut noise:
lowCut = 2;
highCut = 0;
X = x_av(1+lowCut:end-highCut);                 
Y = y_av(1+lowCut:end-highCut);                 
  
% STARTING GUESS MINIMIZATION: 
minimizeAll=1;
if minimizeAll ~= 1
    % minimization for L*, hL*, Hs and Hl 
    usedL = [0.5 1];   
    usedLowerLimits = [];
    usedUpperLimits = [];
else
    %minimization for Lx* and Ly* (Hs & Hl are fixed) 
    usedL = [1 1 1 0.5];
    usedLowerLimits = [];
    usedUpperLimits = [];
end
HSmall = 1.1; % right part of cor spectrum
HLarge = 0.5; % left part of cor spectrum

% Invoke optimization using LSQNONLIN (see Matlab help for details)
[new_L,resnorm] = lsqnonlin(@nonlin_fourier_diff,usedL, usedLowerLimits, usedUpperLimits,options,X,Y, HSmall, HLarge);

if length(new_L)==4
    HSUsed = new_L(3);
    HLUsed = new_L(4);
else
    HSUsed = HSmall;
    HLUsed = HLarge;
end

%calculate the model with minimized coefficients
samplevector = linspace(min(X),max(X),500);
Y_bin        = nonlin_fourier_model(new_L,samplevector, HSUsed, HLUsed);
% Plot the original and modeled data with fixed slopes
figure (3)
loglog (X, Y,'+r',samplevector,exp(Y_bin),'b'),hold on;
loglog (1/new_L(1),new_L(2),'*g')
line([(x_av(end-highCut)) (x_av(end-highCut))],ylim,'Color',[1 0 0])
line([(x_av(1+lowCut)) (x_av(1+lowCut))],ylim,'Color',[1 0 0])
title   ('Fourier power spectrum')
legend ('binned data','modelled fit',...
    sprintf('%s%1.3f%s', 'lc = ',new_L(1),'mm'), ...
    'signal filter')
if minimizeAll==1
    xlabel(sprintf('%s\n%s %1.3f %s %1.3f\n%s', 'a [mm]', 'Hurst exponents: Hs=', HSUsed, ', Hl=', HLUsed, 'Nonlinear fitted values: lc, Hs, Hl'));
else
    xlabel(sprintf('%s\n%s %1.3f %s %1.3f\n%s', 'a [mm]', 'Hurst exponents: Hs=', HSUsed, ', Hl=', HLUsed, 'Nonlinear fitted values: lc'));
end
ylabel('ps(k)');
grid on;
