

function [k_av,ps_av]=logbin1D(k,ps,interval) 
% LOGBIN1D does a logarithmic binning (i.e. the average of all points in a  
% certain interval in log-space) of the Fourier power spectrum as  
% calculated from the fourier1D function. This gives a power spectrum with 
% a constant density in log-space. 
% 
% INPUT VARIABLES: 
%       k           -> wave number of the power spectrum 
%       ps          -> power spectrum over the range of k 
%       interval    -> binning interval (=log(interval))  
% OUTPUT VARIABLES: 
%       k_av        -> linear vector containing averaged wave numbers   
%       ps_av       -> linear vector containing averaged power spectra 
  
 
% logarithmize the input variables  
x        = log(k); 
y        = log(ps); 
bin_size = log(interval); 
  
% initialize first interval 
start    = min(x); 
ende     = start + bin_size; 
i=1; 
  
while ende <= max(x) 
   x_ind   = find(start<=x & x<ende); 
   if(~isempty(x_ind))
       y_av(i) = mean(y(x_ind)');
       x_av(i) = mean(x(x_ind)'); 
       i       = i+1; 
   end
   start   = ende; 
   ende    = ende+bin_size; 
end 
  
k_av     = exp(x_av); 
ps_av    = exp(y_av); 
  
%////////////////////////////////////////////////////////////////////////// 
 
