function [L,Ly,new_L]=nonlin(k,ps,hs,hl,set,output)
%NONLINFIT calculates the nonlinear fit of a function using the definition
%of Ebner et al., 2008 EPSL; NONLINFIT uses the built-in optimization
%function LSQNONLIN with NONLINFIT_COR_DIFF (to minimize the
%difference between the original data and the modeled fit) and
%NONLIN_FOURIER_MODEL (to plot the modeled fit)
% compare functions in Appendix A for details.

X = k; % data range
Y = ps; % original data

% STARTING GUESS MINIMIZATION:
l1 = [0.5 1];
options = optimset('Largescale','on','MaxFunEvals',1000);

% Invoke optimization using LSQNONLIN
[new_L,resnorm] = lsqnonlin(@nonlin_cor_diff,l1,[0.5,0.01],[2,0.5],...
    options,X,Y,hs,hl);
L = new_L(1);
Ly = new_L(2);

% Plot the original and modeled data.
% calculate the model with minimized coefficients
if strcmp(output,'yess')
    samplevector = linspace(min(X),max(X),500);
    Y_bin = nonlin_cor_model(new_L(1:2),samplevector,hs,hl);
    figure
    loglog (X,Y,'+r',samplevector,exp(Y_bin),'b'),hold on;
    plot (1/new_L(1),new_L(2),'*g')
    title ('modeled fit' )
    legend('original data',...
        sprintf('%s %3.3f, ','fit with norm of redsidual=',resnorm),...
        sprintf('%s %1.3f %s', 'crossover =',1/L,'mm'))
end
