function c = nonlin_fourier_diff(l,k,ps,hs,hl)
% The function NONLIN-FOURIER_D describes the nonlinear behaviour of the
% Fourier power spectrum (= fx as a function of L* and Ly) and calculate the
% differences between the function as input for the LSQNONLIN
% function.
% LSQNONLIN minimizes the differences by finding new L* and Ly* values.
%
% IMPUT VARIABLES:
%     l   =>    a [1 2] vector containing starting guess for L* and Ly*
%     k   =>    wave numbers from dataset
%     ps =>     power spectrum from dataset
% OUTPUT VARIABLE:
%     c   =>    vector containing the differences between original and
%               modeled data for all points in the data range
% INITIALISE AND DEFINE THE VARIABLES USED
c       = zeros(size(k));
fx      = zeros(size(k));
x       =   log(k);                 % x values of imput data
L       =   l(1);                   % L* crossover length
Ly      =   l(2);                   % Ly* y-value of L*
if length(l) == 2           %CASE 1: minimize only L* and Ly*
    Hs = hs;                        % predefined Hurst exponents Hs & Hl
    Hl = hl;
else                        %CASE 2: minimize for L*, Ly*, Hs and Hl
    Hs  = l(3);                      % Hs & Hl from starting guess
    Hl  = l(4);
end
alpha_s =   (-1-2*Hs);                % slope of the function  (small scale)
alpha_l =   (-1-2*Hl);                % slope of the function  (large scale)
a       =   log(Ly) + alpha_l*log(L); % intercept of function  (large scale)
b       =   log(Ly) + alpha_s*log(L); % intercept of function  (small scale)
sx      =   (tanh(x+log(L))+1)./2;    % weighting function
% calculate the model and the difference between original and the model
for i=1:length(x)
    fx(i) = ((a + alpha_l*x(i)) * (1-sx(i))) + ((b + alpha_s*x(i)) * (sx(i)));
    c(i) = log(ps(i))-fx(i) ;
end
c = c';                                    % produce a column vector for output
%//////////////////////////////////////////////////////////////////////////
