function c = nonlin_fourier_model(l,k,hs,hl)
%The function NONLIN-FOURIER_M calculates the modeled data using the
%minimized output values from LSQNONLIN over the defined data range.
% IMPUT VARIABLES:
%     l   =>    a vector containing L* and Ly*
%     k   =>    data range to calculate the fit
% OUTPUT VARIABLE:
%     c   =>    vector containing modeled data in log-space values
% INITIALISE AND DEFINE INPUT AND LOCAL VARIABLES
c = zeros(size(k));
x       =   log(k);                 % data range
L       =   l(1);                   % crossover L*
Ly      =   l(2);                   % y-value of crossover L*
if length(l) == 2           %CASE 1: minimize only L and Ly
    Hs = hs;                       % predefined Hs & Hl
    Hl = hl;
else                        %CASE 2: minimize for L*, hL*, Hs and Hl
    Hs  = l(3);                      % Hs & Hl from starting guess
    Hl  = l(4);
end
alpha_s =   (-1-2*Hs);                % slope of the function (small scale)
alpha_l =   (-1-2*Hl);                % slope of the function (large scale)
a       =   log(Ly) + alpha_l*log(L); % intercept of function (large scale)
b       =   log(Ly) + alpha_s*log(L); % intercept of function (small scale)
sx      =   (tanh(x+log(L))+1)./2;    % weighting function
for i = 1:length(x)
    c(i) = ((a + alpha_l*x(i))*(1-sx(i))) + ((b + alpha_s*x(i))*(sx(i)));
end
c = c';
%//////////////////////////////////////////////////////////////////////////
